@@ -185,7 +185,8 @@ def add_blm_skills(skill_library):
         buff_spec=StatusEffectSpec(damage_mult=1.30, duration=15 * 1000),
     )
     enochian_buff_follow_up = FollowUp(
-        skill=enochian_buff, delay_after_parent_application=0
+        skill=enochian_buff, delay_after_parent_application=0,
+        primary_target_only=True
     )
 
     thunderiii_dot = Skill(
@@ -211,6 +212,7 @@ def add_blm_skills(skill_library):
         dot_duration=21 * 1000,
         snapshot_buffs_with_parent=True,
         snapshot_debuffs_with_parent=True,
+        primary_target_only=False
     )
     high_thunder_dot = Skill(
         name="Thunder (dot)",
@@ -235,6 +237,7 @@ def add_blm_skills(skill_library):
         dot_duration=24 * 1000,
         snapshot_buffs_with_parent=True,
         snapshot_debuffs_with_parent=True,
+        primary_target_only=False
     )
 
     skill_library.add_skill(
@@ -479,6 +482,7 @@ def add_blm_skills(skill_library):
             timing_spec=get_enochian_timing_spec_cross(
                 base_cast_time=2800, is_fire_spell=False, application_delay=620
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -516,6 +520,8 @@ def add_blm_skills(skill_library):
                 ),
             ),
             follow_up_skills=(enochian_buff_follow_up,),
+            has_aoe=True,
+            aoe_dropoff=0.4
         )
     )
 
@@ -566,6 +572,7 @@ def add_blm_skills(skill_library):
                 application_delay=1160,
             ),
             follow_up_skills=(thunderiv_follow_up,),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -578,6 +585,8 @@ def add_blm_skills(skill_library):
                 animation_lock=base_animation_lock,
                 application_delay=1160,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -632,6 +641,7 @@ def add_blm_skills(skill_library):
                 ),
             ),
             follow_up_skills=(enochian_buff_follow_up,),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -651,6 +661,7 @@ def add_blm_skills(skill_library):
                 ),
             ),
             follow_up_skills=(enochian_buff_follow_up,),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -736,6 +747,7 @@ def add_blm_skills(skill_library):
                 application_delay=1160,
             ),
             follow_up_skills=(high_thunder_ii_follow_up,),
+            has_aoe=True
         )
     )
     flare_star_damage_spec = get_enochian_damage_spec_cross(
@@ -750,7 +762,9 @@ def add_blm_skills(skill_library):
             is_GCD=True,
             damage_spec=flare_star_damage_spec,
             timing_spec=flare_star_timing_spec,
-        )
+            has_aoe=True,
+            aoe_dropoff=0.65
+        ),
     )
 
     skill_library.add_skill(
