@@ -88,6 +88,7 @@ def add_rdm_skills(skill_library):
     verthunder_2_damage_follow_up = FollowUp(
         skill=Skill(name="Verthunder II", damage_spec=DamageSpec(potency=140)),
         delay_after_parent_application=800,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
@@ -110,12 +111,14 @@ def add_rdm_skills(skill_library):
                 ),
                 "Dualcast": (verthunder_2_damage_follow_up,),
             },
+            has_aoe=True,
         )
     )
 
     veraero_2_damage_follow_up = FollowUp(
         skill=Skill(name="Veraero II", damage_spec=DamageSpec(potency=140)),
         delay_after_parent_application=800,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
@@ -138,6 +141,7 @@ def add_rdm_skills(skill_library):
                 ),
                 "Dualcast": (veraero_2_damage_follow_up,),
             },
+            has_aoe=True,
         )
     )
 
@@ -268,6 +272,7 @@ def add_rdm_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=800
             ),
             status_effect_denylist=("Manafication", "Embolden"),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -279,6 +284,7 @@ def add_rdm_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=1160
             ),
             status_effect_denylist=("Manafication", "Embolden"),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -391,10 +397,12 @@ def add_rdm_skills(skill_library):
     impact_damage_follow_up = FollowUp(
         skill=Skill(name="Impact", damage_spec=DamageSpec(potency=210)),
         delay_after_parent_application=760,
+        primary_target_only=False,
     )
     impact_acceleration_damage_follow_up = FollowUp(
         skill=Skill(name="Impact", damage_spec=DamageSpec(potency=260)),
         delay_after_parent_application=760,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
@@ -425,6 +433,7 @@ def add_rdm_skills(skill_library):
                 "Acceleration": (impact_acceleration_damage_follow_up,),
                 "Acceleration, Dualcast": (impact_acceleration_damage_follow_up,),
             },
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -436,6 +445,8 @@ def add_rdm_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1430
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -447,6 +458,8 @@ def add_rdm_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1430
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -466,6 +479,8 @@ def add_rdm_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1830
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
 
@@ -549,6 +564,8 @@ def add_rdm_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1560
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
 
@@ -561,34 +578,32 @@ def add_rdm_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=630
             ),
             status_effect_denylist=("Manafication", "Embolden"),
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
 
-    grand_impact_damage_follow_up = FollowUp(
-        skill=Skill(name="Grand Impact", damage_spec=DamageSpec(potency=600)),
-        delay_after_parent_application=760,
-    )
     skill_library.add_skill(
         Skill(
             name="Grand Impact",
             is_GCD=True,
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=600)},
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=5000,
                     animation_lock=rdm_caster_tax,
-                    application_delay=0,
+                    application_delay=760,
                 ),
                 "Dualcast": TimingSpec(
-                    base_cast_time=0, animation_lock=650, application_delay=0
+                    base_cast_time=0, animation_lock=650, application_delay=760
                 ),
             },
             follow_up_skills={
-                SimConsts.DEFAULT_CONDITION: (
-                    grand_impact_damage_follow_up,
-                    dualcast_follow_up,
-                ),
-                "Dualcast": (grand_impact_damage_follow_up,),
+                SimConsts.DEFAULT_CONDITION: (dualcast_follow_up,),
+                "Dualcast": tuple(),
             },
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
 
@@ -601,6 +616,8 @@ def add_rdm_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=630
             ),
             status_effect_denylist=("Manafication", "Embolden"),
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
 
@@ -664,6 +681,7 @@ def add_rdm_skills(skill_library):
                 animation_lock=650,
                 application_delay=800,
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -680,6 +698,7 @@ def add_rdm_skills(skill_library):
                 animation_lock=650,
                 application_delay=800,
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -694,6 +713,7 @@ def add_rdm_skills(skill_library):
                 animation_lock=650,
                 application_delay=800,
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -754,14 +774,22 @@ def add_rdm_skills(skill_library):
         Skill(
             name="Verraise",
             is_GCD=True,
-            timing_spec=TimingSpec(base_cast_time=10 * 1000, gcd_base_recast_time=2500, animation_lock=rdm_caster_tax),
+            timing_spec=TimingSpec(
+                base_cast_time=10 * 1000,
+                gcd_base_recast_time=2500,
+                animation_lock=rdm_caster_tax,
+            ),
         )
     )
     skill_library.add_skill(
         Skill(
             name="Vercure",
             is_GCD=True,
-            timing_spec=TimingSpec(base_cast_time=2000, gcd_base_recast_time=2500, animation_lock=rdm_caster_tax),
+            timing_spec=TimingSpec(
+                base_cast_time=2000,
+                gcd_base_recast_time=2500,
+                animation_lock=rdm_caster_tax,
+            ),
         )
     )
 
