@@ -230,7 +230,7 @@ def add_sam_skills(skill_library):
         snapshot_buffs_with_parent=True,
         snapshot_debuffs_with_parent=True,
     )
-    
+
     iaijutsu_timing = TimingSpec(
         base_cast_time=1300,
         affected_by_speed_stat=False,
@@ -299,12 +299,14 @@ def add_sam_skills(skill_library):
     )
 
     magnetsu_follow_up = FollowUp(
-        skill=Skill(name="Magnetsu", damage_spec=DamageSpec(potency=120)),
+        skill=Skill(name="Mangetsu", damage_spec=DamageSpec(potency=120), has_aoe=True),
         delay_after_parent_application=620,
+        primary_target_only=False,
     )
     magnetsu_no_combo_follow_up = FollowUp(
-        skill=Skill(name="Magnetsu", damage_spec=DamageSpec(potency=100)),
+        skill=Skill(name="Mangetsu", damage_spec=DamageSpec(potency=100), has_aoe=True),
         delay_after_parent_application=620,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
@@ -325,6 +327,7 @@ def add_sam_skills(skill_library):
                 SimConsts.DEFAULT_CONDITION: (magnetsu_follow_up, _fugetsu_follow_up),
                 "No Combo": (magnetsu_no_combo_follow_up,),
             },
+            has_aoe=True,
         )
     )
 
@@ -382,12 +385,14 @@ def add_sam_skills(skill_library):
         )
     )
     oka_follow_up = FollowUp(
-        skill=Skill(name="Oka", damage_spec=DamageSpec(potency=120)),
+        skill=Skill(name="Oka", damage_spec=DamageSpec(potency=120), has_aoe=True),
         delay_after_parent_application=620,
+        primary_target_only=False,
     )
     oka_no_combo_follow_up = FollowUp(
-        skill=Skill(name="Oka", damage_spec=DamageSpec(potency=100)),
+        skill=Skill(name="Oka", damage_spec=DamageSpec(potency=100), has_aoe=True),
         delay_after_parent_application=620,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
@@ -408,6 +413,7 @@ def add_sam_skills(skill_library):
                 SimConsts.DEFAULT_CONDITION: (oka_follow_up, _fuka_follow_up),
                 "No Combo": (oka_no_combo_follow_up,),
             },
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -469,6 +475,7 @@ def add_sam_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -479,6 +486,8 @@ def add_sam_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
+            has_aoe=True,
+            aoe_dropoff=0.25,
         )
     )
     skill_library.add_skill(
@@ -499,6 +508,8 @@ def add_sam_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=580
             ),
+            has_aoe=True,
+            aoe_dropoff=0.65,
         )
     )
     skill_library.add_skill(
@@ -510,6 +521,7 @@ def add_sam_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=760
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -525,6 +537,8 @@ def add_sam_skills(skill_library):
                 affected_by_haste_buffs=False,
                 application_delay=490,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.75,
         )
     )
     skill_library.add_skill(
@@ -537,6 +551,8 @@ def add_sam_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=490
             ),
+            has_aoe=True,
+            aoe_dropoff=0.75,
         )
     )
     skill_library.add_skill(
@@ -547,6 +563,8 @@ def add_sam_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=580
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -599,7 +617,7 @@ def add_sam_skills(skill_library):
             ),
         )
     )
-        
+
     skill_library.add_skill(
         Skill(
             name="Meikyo Shisui",
