@@ -62,8 +62,8 @@ def add_war_skills(skill_library):
             ),
             combo_spec=(ComboSpec(combo_actions=("Maim",)),),
             damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=460),
-                "No Combo": DamageSpec(potency=180),
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=480),
+                "No Combo": DamageSpec(potency=200),
             },
         )
     )
@@ -90,15 +90,17 @@ def add_war_skills(skill_library):
         ),
     )
     surging_tempest_follow_up = FollowUp(
-        skill=surging_tempest_skill, delay_after_parent_application=0
+        skill=surging_tempest_skill,
+        delay_after_parent_application=0,
+        primary_target_only=True,
     )
 
     storms_eye_damage_follow_up = FollowUp(
-        skill=Skill(name="Storm's Eye", damage_spec=DamageSpec(potency=460)),
+        skill=Skill(name="Storm's Eye", damage_spec=DamageSpec(potency=480)),
         delay_after_parent_application=1649,
     )
     storms_eye_damage_no_combo_follow_up = FollowUp(
-        skill=Skill(name="Storm's Eye", damage_spec=DamageSpec(potency=180)),
+        skill=Skill(name="Storm's Eye", damage_spec=DamageSpec(potency=200)),
         delay_after_parent_application=1649,
     )
     skill_library.add_skill(
@@ -147,7 +149,7 @@ def add_war_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
-            damage_spec=DamageSpec(potency=540),
+            damage_spec=DamageSpec(potency=580),
         )
     )
     skill_library.add_skill(
@@ -157,11 +159,12 @@ def add_war_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=1300, application_delay=1160
             ),
-            damage_spec=DamageSpec(
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(
                 potency=700,
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
-                guaranteed_dh=ForcedCritOrDH.FORCE_YES,
-            ),
+                guaranteed_dh=ForcedCritOrDH.FORCE_YES)},            
+            has_aoe=True,
+            aoe_dropoff=0.7,
         )
     )
     skill_library.add_skill(
@@ -190,6 +193,7 @@ def add_war_skills(skill_library):
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                 guaranteed_dh=ForcedCritOrDH.FORCE_YES,
             ),
+            has_aoe=True,
         )
     )
 
@@ -212,6 +216,7 @@ def add_war_skills(skill_library):
             ),
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=110),
+            has_aoe=True,
         )
     )
 
@@ -225,16 +230,20 @@ def add_war_skills(skill_library):
         ),
     )
     mythril_tempest_inital_follow_up = FollowUp(
-        skill=mythril_tempest_skill_inital, delay_after_parent_application=0
+        skill=mythril_tempest_skill_inital,
+        delay_after_parent_application=0,
+        primary_target_only=True,
     )
 
     mythril_tempest_damage_follow_up = FollowUp(
         skill=Skill(name="Mythril Tempest", damage_spec=DamageSpec(potency=140)),
         delay_after_parent_application=490,
+        primary_target_only=False,
     )
     mythril_tempest_damage_no_combo_follow_up = FollowUp(
-        skill=Skill(name="_Storm's Eye", damage_spec=DamageSpec(potency=100)),
+        skill=Skill(name="Mythril Tempest", damage_spec=DamageSpec(potency=100)),
         delay_after_parent_application=490,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
@@ -253,6 +262,7 @@ def add_war_skills(skill_library):
                 ),
                 "No Combo": (mythril_tempest_damage_no_combo_follow_up,),
             },
+            has_aoe=True,
         )
     )
 
@@ -264,6 +274,7 @@ def add_war_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=668
             ),
             damage_spec=DamageSpec(potency=150),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -274,6 +285,7 @@ def add_war_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=1831
             ),
             damage_spec=DamageSpec(potency=180),
+            has_aoe=True,
         )
     )
 
@@ -314,9 +326,11 @@ def add_war_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
-            damage_spec=DamageSpec(potency=600),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=700)},
+            has_aoe=True,
+            aoe_dropoff=0.7,
         )
-    )    
+    )
     skill_library.add_skill(
         Skill(
             name="Primal Ruination",
@@ -324,11 +338,15 @@ def add_war_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=1300, application_delay=1160
             ),
-            damage_spec=DamageSpec(
-                potency=740,
-                guaranteed_crit=ForcedCritOrDH.FORCE_YES,
-                guaranteed_dh=ForcedCritOrDH.FORCE_YES,
-            ),
+            damage_spec={
+                SimConsts.DEFAULT_CONDITION: DamageSpec(
+                    potency=740,
+                    guaranteed_crit=ForcedCritOrDH.FORCE_YES,
+                    guaranteed_dh=ForcedCritOrDH.FORCE_YES,
+                )
+            },
+            has_aoe=True,
+            aoe_dropoff=0.7,
         )
     )
     # These skills do not damage, but grants resources/affects future skills.
@@ -358,7 +376,7 @@ def add_war_skills(skill_library):
                 ),
             },
         )
-    )    
+    )
     skill_library.add_skill(
         Skill(name="Holmgang", is_GCD=False, timing_spec=instant_timing_spec)
     )
